@@ -1,17 +1,18 @@
-alloroot<-function(vecs,roots,sibord,levels,volumes){
-#
+alloroot<-function(vecs,roots,sibord,levels,volumes)
+{
 rootnum<-length(roots)
+
 # Calculate sum of volumes of roots
 rootsvolume<-0
 for (i in 1:rootnum){
   now<-roots[i]
   rootsvolume<-rootsvolume+volumes[now]
 }
-#
+
 basis<-rootsvolume+rootsvolume/4
-# 
+ 
 gaplen<-(basis-rootsvolume)/(rootnum+1)
-#
+
 rootlinks<-matrix(0,rootnum,1)  #make links in right order
 
 if (rootnum==1) rootlinks[1]<-1
