@@ -1,14 +1,14 @@
 graph.matrix<-function(dendat,type="level",
 tt=NULL,permu=seq(1:dim(dendat)[1]),col=seq(1:2000),
 config="new",shift=0.1,segme=TRUE,poin=FALSE,epsi=0,ystart=0.5, 
-pch=21, cex=1,
+pch=21, cex=1, cex.axis=1, yaxt="s",
 # profile:
 ylen=100,profcol=rep("black",n))
 {
 if (type=="level") 
  graph.matrix.level(dendat, tt=tt, permu=permu, col=col,
  config=config, shift=shift, segme=segme, poin=poin, epsi=epsi, ystart=ystart,
- pch=pch, cex=cex)
+ pch=pch, cex=cex, yaxt=yaxt, cex.axis=cex.axis)
 
 else{  # type="profile"
  n<-dim(dendat)[1]
