@@ -1,6 +1,6 @@
 qq.plot<-function(dendat=NULL,compa="gauss",basis="gauss",
 mean=0,sig=1,df=1,
-gnum=1000,d=1,R=3,qqtype="1d")
+gnum=1000,d=1,R=3,qqtype="1d",cex.lab=1,cex.axis=1,col="blue",lwd=1)
 {
 if (qqtype=="1d"){
    n<-length(dendat) #dim(dendat)[1]
@@ -42,10 +42,10 @@ if (qqtype=="p2v"){
      xlab<-"model"
 }
 
-plot(x,y,type=tyyppi,ylab=ylab,xlab=xlab)
+plot(x,y,type=tyyppi,ylab=ylab,xlab=xlab,cex.lab=cex.lab,cex.axis=cex.axis)
 maxxy<-max(max(x),max(y))
 minxy<-min(min(x),min(y))
-segments(minxy,minxy,maxxy,maxxy,col="green")
+segments(minxy,minxy,maxxy,maxxy,col=col,lwd=lwd)
 }
 
 
